# Release notes

```{note}
For now, Eradiate uses a [ZeroVer](https://0ver.org) versioning
scheme. It reflects the relative instability of our API: breaking changes may
happen at any time. We plan to switch to a versioning scheme more similar to
SemVer in the future.

Updates are tracked in this change log. Every time you decide to update to a
newer version, we recommend that you to go through the list of changes.
We try hard to remain backward-compatible and warn in advance for deprecation
when necessary—we also advise to not ignore `DeprecationWarning`s.

Emoji marks have the following meaning:

* ⚠️ Requires particular attention during upgrade or usage
  (breaking change or experimental feature).
* 📖 Documentation-related change.
* 🖥️ This is a developer-facing change.
```

```{toctree}
:maxdepth: 2

v0.26.x.md
v0.25.x.md
v0.24.x.md
v0.23.x_and_older.md
```

This is the list of changes to Eradiate between each release.
For the full change log, see the [commit logs](https://github.com/eradiate/eradiate/commits/).

% HEREAFTER IS A TEMPLATE FOR THE NEXT RELEASE
%
% ## vXX.YY.ZZ (upcoming release)
%
% ### Deprecated
%
% ### Removed
%
% ### Added
%
% ### Changed
%
% ### Fixed
%
% ### Internal changes
